from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from teralytic.api.field_api import FieldApi
from teralytic.api.organization_api import OrganizationApi
from teralytic.api.probe_api import ProbeApi



# coding: utf-8

"""
    teralytic

    Teralytic-API allows customers and partners to view their probes, sensor readings for each, as well as analytics and calculations from Teralytic algorithms.  # noqa: E501

    OpenAPI spec version: 1.0.5
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class WeatherData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'weather_summary': 'str',
        'precip_type': 'str',
        'apparent_temp': 'float',
        'cloud_cover': 'float',
        'dew_point': 'float',
        'humidity': 'float',
        'ozone': 'float',
        'precip_intensity': 'float',
        'precip_probability': 'float',
        'pressure': 'float',
        'temperature': 'float',
        'time': 'float',
        'uv_index': 'int',
        'wind_bearing': 'int',
        'wind_gust': 'float',
        'wind_speed': 'float',
        'visibility': 'float'
    }

    attribute_map = {
        'weather_summary': 'weather_summary',
        'precip_type': 'precip_type',
        'apparent_temp': 'apparent_temp',
        'cloud_cover': 'cloud_cover',
        'dew_point': 'dew_point',
        'humidity': 'humidity',
        'ozone': 'ozone',
        'precip_intensity': 'precip_intensity',
        'precip_probability': 'precip_probability',
        'pressure': 'pressure',
        'temperature': 'temperature',
        'time': 'time',
        'uv_index': 'uv_index',
        'wind_bearing': 'wind_bearing',
        'wind_gust': 'wind_gust',
        'wind_speed': 'wind_speed',
        'visibility': 'visibility'
    }

    def __init__(self, weather_summary=None, precip_type=None, apparent_temp=None, cloud_cover=None, dew_point=None, humidity=None, ozone=None, precip_intensity=None, precip_probability=None, pressure=None, temperature=None, time=None, uv_index=None, wind_bearing=None, wind_gust=None, wind_speed=None, visibility=None):  # noqa: E501
        """WeatherData - a model defined in Swagger"""  # noqa: E501

        self._weather_summary = None
        self._precip_type = None
        self._apparent_temp = None
        self._cloud_cover = None
        self._dew_point = None
        self._humidity = None
        self._ozone = None
        self._precip_intensity = None
        self._precip_probability = None
        self._pressure = None
        self._temperature = None
        self._time = None
        self._uv_index = None
        self._wind_bearing = None
        self._wind_gust = None
        self._wind_speed = None
        self._visibility = None
        self.discriminator = None

        if weather_summary is not None:
            self.weather_summary = weather_summary
        if precip_type is not None:
            self.precip_type = precip_type
        if apparent_temp is not None:
            self.apparent_temp = apparent_temp
        if cloud_cover is not None:
            self.cloud_cover = cloud_cover
        if dew_point is not None:
            self.dew_point = dew_point
        if humidity is not None:
            self.humidity = humidity
        if ozone is not None:
            self.ozone = ozone
        if precip_intensity is not None:
            self.precip_intensity = precip_intensity
        if precip_probability is not None:
            self.precip_probability = precip_probability
        if pressure is not None:
            self.pressure = pressure
        if temperature is not None:
            self.temperature = temperature
        if time is not None:
            self.time = time
        if uv_index is not None:
            self.uv_index = uv_index
        if wind_bearing is not None:
            self.wind_bearing = wind_bearing
        if wind_gust is not None:
            self.wind_gust = wind_gust
        if wind_speed is not None:
            self.wind_speed = wind_speed
        if visibility is not None:
            self.visibility = visibility

    @property
    def weather_summary(self):
        """Gets the weather_summary of this WeatherData.  # noqa: E501

        Weather Summary  # noqa: E501

        :return: The weather_summary of this WeatherData.  # noqa: E501
        :rtype: str
        """
        return self._weather_summary

    @weather_summary.setter
    def weather_summary(self, weather_summary):
        """Sets the weather_summary of this WeatherData.

        Weather Summary  # noqa: E501

        :param weather_summary: The weather_summary of this WeatherData.  # noqa: E501
        :type: str
        """

        self._weather_summary = weather_summary

    @property
    def precip_type(self):
        """Gets the precip_type of this WeatherData.  # noqa: E501

        Precipitation Type  # noqa: E501

        :return: The precip_type of this WeatherData.  # noqa: E501
        :rtype: str
        """
        return self._precip_type

    @precip_type.setter
    def precip_type(self, precip_type):
        """Sets the precip_type of this WeatherData.

        Precipitation Type  # noqa: E501

        :param precip_type: The precip_type of this WeatherData.  # noqa: E501
        :type: str
        """

        self._precip_type = precip_type

    @property
    def apparent_temp(self):
        """Gets the apparent_temp of this WeatherData.  # noqa: E501

        Apparent Temperature  # noqa: E501

        :return: The apparent_temp of this WeatherData.  # noqa: E501
        :rtype: float
        """
        return self._apparent_temp

    @apparent_temp.setter
    def apparent_temp(self, apparent_temp):
        """Sets the apparent_temp of this WeatherData.

        Apparent Temperature  # noqa: E501

        :param apparent_temp: The apparent_temp of this WeatherData.  # noqa: E501
        :type: float
        """

        self._apparent_temp = apparent_temp

    @property
    def cloud_cover(self):
        """Gets the cloud_cover of this WeatherData.  # noqa: E501

        Cloud Cover  # noqa: E501

        :return: The cloud_cover of this WeatherData.  # noqa: E501
        :rtype: float
        """
        return self._cloud_cover

    @cloud_cover.setter
    def cloud_cover(self, cloud_cover):
        """Sets the cloud_cover of this WeatherData.

        Cloud Cover  # noqa: E501

        :param cloud_cover: The cloud_cover of this WeatherData.  # noqa: E501
        :type: float
        """

        self._cloud_cover = cloud_cover

    @property
    def dew_point(self):
        """Gets the dew_point of this WeatherData.  # noqa: E501

        Dew Point  # noqa: E501

        :return: The dew_point of this WeatherData.  # noqa: E501
        :rtype: float
        """
        return self._dew_point

    @dew_point.setter
    def dew_point(self, dew_point):
        """Sets the dew_point of this WeatherData.

        Dew Point  # noqa: E501

        :param dew_point: The dew_point of this WeatherData.  # noqa: E501
        :type: float
        """

        self._dew_point = dew_point

    @property
    def humidity(self):
        """Gets the humidity of this WeatherData.  # noqa: E501

        Humidity  # noqa: E501

        :return: The humidity of this WeatherData.  # noqa: E501
        :rtype: float
        """
        return self._humidity

    @humidity.setter
    def humidity(self, humidity):
        """Sets the humidity of this WeatherData.

        Humidity  # noqa: E501

        :param humidity: The humidity of this WeatherData.  # noqa: E501
        :type: float
        """

        self._humidity = humidity

    @property
    def ozone(self):
        """Gets the ozone of this WeatherData.  # noqa: E501

        Ozone Rating  # noqa: E501

        :return: The ozone of this WeatherData.  # noqa: E501
        :rtype: float
        """
        return self._ozone

    @ozone.setter
    def ozone(self, ozone):
        """Sets the ozone of this WeatherData.

        Ozone Rating  # noqa: E501

        :param ozone: The ozone of this WeatherData.  # noqa: E501
        :type: float
        """

        self._ozone = ozone

    @property
    def precip_intensity(self):
        """Gets the precip_intensity of this WeatherData.  # noqa: E501

        Precipitation Intesity  # noqa: E501

        :return: The precip_intensity of this WeatherData.  # noqa: E501
        :rtype: float
        """
        return self._precip_intensity

    @precip_intensity.setter
    def precip_intensity(self, precip_intensity):
        """Sets the precip_intensity of this WeatherData.

        Precipitation Intesity  # noqa: E501

        :param precip_intensity: The precip_intensity of this WeatherData.  # noqa: E501
        :type: float
        """

        self._precip_intensity = precip_intensity

    @property
    def precip_probability(self):
        """Gets the precip_probability of this WeatherData.  # noqa: E501

        Precipitation Probability  # noqa: E501

        :return: The precip_probability of this WeatherData.  # noqa: E501
        :rtype: float
        """
        return self._precip_probability

    @precip_probability.setter
    def precip_probability(self, precip_probability):
        """Sets the precip_probability of this WeatherData.

        Precipitation Probability  # noqa: E501

        :param precip_probability: The precip_probability of this WeatherData.  # noqa: E501
        :type: float
        """

        self._precip_probability = precip_probability

    @property
    def pressure(self):
        """Gets the pressure of this WeatherData.  # noqa: E501

        Barometric Pressure  # noqa: E501

        :return: The pressure of this WeatherData.  # noqa: E501
        :rtype: float
        """
        return self._pressure

    @pressure.setter
    def pressure(self, pressure):
        """Sets the pressure of this WeatherData.

        Barometric Pressure  # noqa: E501

        :param pressure: The pressure of this WeatherData.  # noqa: E501
        :type: float
        """

        self._pressure = pressure

    @property
    def temperature(self):
        """Gets the temperature of this WeatherData.  # noqa: E501

        Temperature  # noqa: E501

        :return: The temperature of this WeatherData.  # noqa: E501
        :rtype: float
        """
        return self._temperature

    @temperature.setter
    def temperature(self, temperature):
        """Sets the temperature of this WeatherData.

        Temperature  # noqa: E501

        :param temperature: The temperature of this WeatherData.  # noqa: E501
        :type: float
        """

        self._temperature = temperature

    @property
    def time(self):
        """Gets the time of this WeatherData.  # noqa: E501

        Weather Sample Time (epoch)  # noqa: E501

        :return: The time of this WeatherData.  # noqa: E501
        :rtype: float
        """
        return self._time

    @time.setter
    def time(self, time):
        """Sets the time of this WeatherData.

        Weather Sample Time (epoch)  # noqa: E501

        :param time: The time of this WeatherData.  # noqa: E501
        :type: float
        """

        self._time = time

    @property
    def uv_index(self):
        """Gets the uv_index of this WeatherData.  # noqa: E501

        UV Index  # noqa: E501

        :return: The uv_index of this WeatherData.  # noqa: E501
        :rtype: int
        """
        return self._uv_index

    @uv_index.setter
    def uv_index(self, uv_index):
        """Sets the uv_index of this WeatherData.

        UV Index  # noqa: E501

        :param uv_index: The uv_index of this WeatherData.  # noqa: E501
        :type: int
        """

        self._uv_index = uv_index

    @property
    def wind_bearing(self):
        """Gets the wind_bearing of this WeatherData.  # noqa: E501

        Wind Bearing  # noqa: E501

        :return: The wind_bearing of this WeatherData.  # noqa: E501
        :rtype: int
        """
        return self._wind_bearing

    @wind_bearing.setter
    def wind_bearing(self, wind_bearing):
        """Sets the wind_bearing of this WeatherData.

        Wind Bearing  # noqa: E501

        :param wind_bearing: The wind_bearing of this WeatherData.  # noqa: E501
        :type: int
        """

        self._wind_bearing = wind_bearing

    @property
    def wind_gust(self):
        """Gets the wind_gust of this WeatherData.  # noqa: E501

        Wind Gust  # noqa: E501

        :return: The wind_gust of this WeatherData.  # noqa: E501
        :rtype: float
        """
        return self._wind_gust

    @wind_gust.setter
    def wind_gust(self, wind_gust):
        """Sets the wind_gust of this WeatherData.

        Wind Gust  # noqa: E501

        :param wind_gust: The wind_gust of this WeatherData.  # noqa: E501
        :type: float
        """

        self._wind_gust = wind_gust

    @property
    def wind_speed(self):
        """Gets the wind_speed of this WeatherData.  # noqa: E501

        Wind Speed  # noqa: E501

        :return: The wind_speed of this WeatherData.  # noqa: E501
        :rtype: float
        """
        return self._wind_speed

    @wind_speed.setter
    def wind_speed(self, wind_speed):
        """Sets the wind_speed of this WeatherData.

        Wind Speed  # noqa: E501

        :param wind_speed: The wind_speed of this WeatherData.  # noqa: E501
        :type: float
        """

        self._wind_speed = wind_speed

    @property
    def visibility(self):
        """Gets the visibility of this WeatherData.  # noqa: E501

        Visibility  # noqa: E501

        :return: The visibility of this WeatherData.  # noqa: E501
        :rtype: float
        """
        return self._visibility

    @visibility.setter
    def visibility(self, visibility):
        """Sets the visibility of this WeatherData.

        Visibility  # noqa: E501

        :param visibility: The visibility of this WeatherData.  # noqa: E501
        :type: float
        """

        self._visibility = visibility

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WeatherData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    teralytic

    Teralytic-API allows customers and partners to view their probes, sensor readings for each, as well as analytics and calculations from Teralytic algorithms.  # noqa: E501

    OpenAPI spec version: 1.0.5
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import teralytic
from teralytic.models.reading_location import ReadingLocation  # noqa: E501
from teralytic.rest import ApiException


class TestReadingLocation(unittest.TestCase):
    """ReadingLocation unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testReadingLocation(self):
        """Test ReadingLocation"""
        # FIXME: construct object with mandatory attributes with example values
        # model = teralytic.models.reading_location.ReadingLocation()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    teralytic

    Teralytic-API allows customers and partners to view their probes, sensor readings for each, as well as analytics and calculations from Teralytic algorithms.  # noqa: E501

    OpenAPI spec version: 1.0.5
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from teralytic.models.field_geometry import FieldGeometry  # noqa: F401,E501


class Field(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'organization_id': 'str',
        'name': 'str',
        'acreage': 'float',
        'crop': 'str',
        'geometry': 'FieldGeometry'
    }

    attribute_map = {
        'id': 'id',
        'organization_id': 'organization_id',
        'name': 'name',
        'acreage': 'acreage',
        'crop': 'crop',
        'geometry': 'geometry'
    }

    def __init__(self, id=None, organization_id=None, name=None, acreage=None, crop=None, geometry=None):  # noqa: E501
        """Field - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._organization_id = None
        self._name = None
        self._acreage = None
        self._crop = None
        self._geometry = None
        self.discriminator = None

        self.id = id
        if organization_id is not None:
            self.organization_id = organization_id
        self.name = name
        if acreage is not None:
            self.acreage = acreage
        if crop is not None:
            self.crop = crop
        if geometry is not None:
            self.geometry = geometry

    @property
    def id(self):
        """Gets the id of this Field.  # noqa: E501


        :return: The id of this Field.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Field.


        :param id: The id of this Field.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def organization_id(self):
        """Gets the organization_id of this Field.  # noqa: E501


        :return: The organization_id of this Field.  # noqa: E501
        :rtype: str
        """
        return self._organization_id

    @organization_id.setter
    def organization_id(self, organization_id):
        """Sets the organization_id of this Field.


        :param organization_id: The organization_id of this Field.  # noqa: E501
        :type: str
        """

        self._organization_id = organization_id

    @property
    def name(self):
        """Gets the name of this Field.  # noqa: E501


        :return: The name of this Field.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Field.


        :param name: The name of this Field.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def acreage(self):
        """Gets the acreage of this Field.  # noqa: E501


        :return: The acreage of this Field.  # noqa: E501
        :rtype: float
        """
        return self._acreage

    @acreage.setter
    def acreage(self, acreage):
        """Sets the acreage of this Field.


        :param acreage: The acreage of this Field.  # noqa: E501
        :type: float
        """

        self._acreage = acreage

    @property
    def crop(self):
        """Gets the crop of this Field.  # noqa: E501


        :return: The crop of this Field.  # noqa: E501
        :rtype: str
        """
        return self._crop

    @crop.setter
    def crop(self, crop):
        """Sets the crop of this Field.


        :param crop: The crop of this Field.  # noqa: E501
        :type: str
        """

        self._crop = crop

    @property
    def geometry(self):
        """Gets the geometry of this Field.  # noqa: E501


        :return: The geometry of this Field.  # noqa: E501
        :rtype: FieldGeometry
        """
        return self._geometry

    @geometry.setter
    def geometry(self, geometry):
        """Sets the geometry of this Field.


        :param geometry: The geometry of this Field.  # noqa: E501
        :type: FieldGeometry
        """

        self._geometry = geometry

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Field):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    teralytic

    Teralytic-API allows customers and partners to view their probes, sensor readings for each, as well as analytics and calculations from Teralytic algorithms.  # noqa: E501

    OpenAPI spec version: 1.0.5
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class DepthReading(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'depth': 'int',
        'depth_units': 'str',
        'terascore': 'float',
        'nitrogen': 'float',
        'nitrogen_ppm': 'float',
        'phosphorus': 'float',
        'phosphorus_ppm': 'float',
        'potassium': 'float',
        'potassium_ppm': 'float',
        'ec': 'float',
        'o2': 'float',
        'p_h': 'float',
        'co2': 'float',
        'awc': 'float',
        'soil_moisture': 'float',
        'soil_temperature': 'float',
        'soil_texture': 'str'
    }

    attribute_map = {
        'depth': 'depth',
        'depth_units': 'depth_units',
        'terascore': 'terascore',
        'nitrogen': 'nitrogen',
        'nitrogen_ppm': 'nitrogen_ppm',
        'phosphorus': 'phosphorus',
        'phosphorus_ppm': 'phosphorus_ppm',
        'potassium': 'potassium',
        'potassium_ppm': 'potassium_ppm',
        'ec': 'ec',
        'o2': 'o2',
        'p_h': 'pH',
        'co2': 'co2',
        'awc': 'awc',
        'soil_moisture': 'soil_moisture',
        'soil_temperature': 'soil_temperature',
        'soil_texture': 'soil_texture'
    }

    def __init__(self, depth=None, depth_units=None, terascore=None, nitrogen=None, nitrogen_ppm=None, phosphorus=None, phosphorus_ppm=None, potassium=None, potassium_ppm=None, ec=None, o2=None, p_h=None, co2=None, awc=None, soil_moisture=None, soil_temperature=None, soil_texture=None):  # noqa: E501
        """DepthReading - a model defined in Swagger"""  # noqa: E501

        self._depth = None
        self._depth_units = None
        self._terascore = None
        self._nitrogen = None
        self._nitrogen_ppm = None
        self._phosphorus = None
        self._phosphorus_ppm = None
        self._potassium = None
        self._potassium_ppm = None
        self._ec = None
        self._o2 = None
        self._p_h = None
        self._co2 = None
        self._awc = None
        self._soil_moisture = None
        self._soil_temperature = None
        self._soil_texture = None
        self.discriminator = None

        if depth is not None:
            self.depth = depth
        if depth_units is not None:
            self.depth_units = depth_units
        if terascore is not None:
            self.terascore = terascore
        if nitrogen is not None:
            self.nitrogen = nitrogen
        if nitrogen_ppm is not None:
            self.nitrogen_ppm = nitrogen_ppm
        if phosphorus is not None:
            self.phosphorus = phosphorus
        if phosphorus_ppm is not None:
            self.phosphorus_ppm = phosphorus_ppm
        if potassium is not None:
            self.potassium = potassium
        if potassium_ppm is not None:
            self.potassium_ppm = potassium_ppm
        if ec is not None:
            self.ec = ec
        if o2 is not None:
            self.o2 = o2
        if p_h is not None:
            self.p_h = p_h
        if co2 is not None:
            self.co2 = co2
        if awc is not None:
            self.awc = awc
        if soil_moisture is not None:
            self.soil_moisture = soil_moisture
        if soil_temperature is not None:
            self.soil_temperature = soil_temperature
        if soil_texture is not None:
            self.soil_texture = soil_texture

    @property
    def depth(self):
        """Gets the depth of this DepthReading.  # noqa: E501

        The depth value  # noqa: E501

        :return: The depth of this DepthReading.  # noqa: E501
        :rtype: int
        """
        return self._depth

    @depth.setter
    def depth(self, depth):
        """Sets the depth of this DepthReading.

        The depth value  # noqa: E501

        :param depth: The depth of this DepthReading.  # noqa: E501
        :type: int
        """

        self._depth = depth

    @property
    def depth_units(self):
        """Gets the depth_units of this DepthReading.  # noqa: E501

        The depth units (i.e. in, cm)  # noqa: E501

        :return: The depth_units of this DepthReading.  # noqa: E501
        :rtype: str
        """
        return self._depth_units

    @depth_units.setter
    def depth_units(self, depth_units):
        """Sets the depth_units of this DepthReading.

        The depth units (i.e. in, cm)  # noqa: E501

        :param depth_units: The depth_units of this DepthReading.  # noqa: E501
        :type: str
        """

        self._depth_units = depth_units

    @property
    def terascore(self):
        """Gets the terascore of this DepthReading.  # noqa: E501

        TeraScore  # noqa: E501

        :return: The terascore of this DepthReading.  # noqa: E501
        :rtype: float
        """
        return self._terascore

    @terascore.setter
    def terascore(self, terascore):
        """Sets the terascore of this DepthReading.

        TeraScore  # noqa: E501

        :param terascore: The terascore of this DepthReading.  # noqa: E501
        :type: float
        """

        self._terascore = terascore

    @property
    def nitrogen(self):
        """Gets the nitrogen of this DepthReading.  # noqa: E501

        Nitrogen  # noqa: E501

        :return: The nitrogen of this DepthReading.  # noqa: E501
        :rtype: float
        """
        return self._nitrogen

    @nitrogen.setter
    def nitrogen(self, nitrogen):
        """Sets the nitrogen of this DepthReading.

        Nitrogen  # noqa: E501

        :param nitrogen: The nitrogen of this DepthReading.  # noqa: E501
        :type: float
        """

        self._nitrogen = nitrogen

    @property
    def nitrogen_ppm(self):
        """Gets the nitrogen_ppm of this DepthReading.  # noqa: E501

        Nitrogen ppm  # noqa: E501

        :return: The nitrogen_ppm of this DepthReading.  # noqa: E501
        :rtype: float
        """
        return self._nitrogen_ppm

    @nitrogen_ppm.setter
    def nitrogen_ppm(self, nitrogen_ppm):
        """Sets the nitrogen_ppm of this DepthReading.

        Nitrogen ppm  # noqa: E501

        :param nitrogen_ppm: The nitrogen_ppm of this DepthReading.  # noqa: E501
        :type: float
        """

        self._nitrogen_ppm = nitrogen_ppm

    @property
    def phosphorus(self):
        """Gets the phosphorus of this DepthReading.  # noqa: E501

        Phosphorus  # noqa: E501

        :return: The phosphorus of this DepthReading.  # noqa: E501
        :rtype: float
        """
        return self._phosphorus

    @phosphorus.setter
    def phosphorus(self, phosphorus):
        """Sets the phosphorus of this DepthReading.

        Phosphorus  # noqa: E501

        :param phosphorus: The phosphorus of this DepthReading.  # noqa: E501
        :type: float
        """

        self._phosphorus = phosphorus

    @property
    def phosphorus_ppm(self):
        """Gets the phosphorus_ppm of this DepthReading.  # noqa: E501

        Phosphorus ppm  # noqa: E501

        :return: The phosphorus_ppm of this DepthReading.  # noqa: E501
        :rtype: float
        """
        return self._phosphorus_ppm

    @phosphorus_ppm.setter
    def phosphorus_ppm(self, phosphorus_ppm):
        """Sets the phosphorus_ppm of this DepthReading.

        Phosphorus ppm  # noqa: E501

        :param phosphorus_ppm: The phosphorus_ppm of this DepthReading.  # noqa: E501
        :type: float
        """

        self._phosphorus_ppm = phosphorus_ppm

    @property
    def potassium(self):
        """Gets the potassium of this DepthReading.  # noqa: E501

        Potassium  # noqa: E501

        :return: The potassium of this DepthReading.  # noqa: E501
        :rtype: float
        """
        return self._potassium

    @potassium.setter
    def potassium(self, potassium):
        """Sets the potassium of this DepthReading.

        Potassium  # noqa: E501

        :param potassium: The potassium of this DepthReading.  # noqa: E501
        :type: float
        """

        self._potassium = potassium

    @property
    def potassium_ppm(self):
        """Gets the potassium_ppm of this DepthReading.  # noqa: E501

        Potassium ppm  # noqa: E501

        :return: The potassium_ppm of this DepthReading.  # noqa: E501
        :rtype: float
        """
        return self._potassium_ppm

    @potassium_ppm.setter
    def potassium_ppm(self, potassium_ppm):
        """Sets the potassium_ppm of this DepthReading.

        Potassium ppm  # noqa: E501

        :param potassium_ppm: The potassium_ppm of this DepthReading.  # noqa: E501
        :type: float
        """

        self._potassium_ppm = potassium_ppm

    @property
    def ec(self):
        """Gets the ec of this DepthReading.  # noqa: E501

        Electrical Conductivity  # noqa: E501

        :return: The ec of this DepthReading.  # noqa: E501
        :rtype: float
        """
        return self._ec

    @ec.setter
    def ec(self, ec):
        """Sets the ec of this DepthReading.

        Electrical Conductivity  # noqa: E501

        :param ec: The ec of this DepthReading.  # noqa: E501
        :type: float
        """

        self._ec = ec

    @property
    def o2(self):
        """Gets the o2 of this DepthReading.  # noqa: E501

        Dioxygen  # noqa: E501

        :return: The o2 of this DepthReading.  # noqa: E501
        :rtype: float
        """
        return self._o2

    @o2.setter
    def o2(self, o2):
        """Sets the o2 of this DepthReading.

        Dioxygen  # noqa: E501

        :param o2: The o2 of this DepthReading.  # noqa: E501
        :type: float
        """

        self._o2 = o2

    @property
    def p_h(self):
        """Gets the p_h of this DepthReading.  # noqa: E501

        pH Scale  # noqa: E501

        :return: The p_h of this DepthReading.  # noqa: E501
        :rtype: float
        """
        return self._p_h

    @p_h.setter
    def p_h(self, p_h):
        """Sets the p_h of this DepthReading.

        pH Scale  # noqa: E501

        :param p_h: The p_h of this DepthReading.  # noqa: E501
        :type: float
        """

        self._p_h = p_h

    @property
    def co2(self):
        """Gets the co2 of this DepthReading.  # noqa: E501

        Carbon Dioxide  # noqa: E501

        :return: The co2 of this DepthReading.  # noqa: E501
        :rtype: float
        """
        return self._co2

    @co2.setter
    def co2(self, co2):
        """Sets the co2 of this DepthReading.

        Carbon Dioxide  # noqa: E501

        :param co2: The co2 of this DepthReading.  # noqa: E501
        :type: float
        """

        self._co2 = co2

    @property
    def awc(self):
        """Gets the awc of this DepthReading.  # noqa: E501


        :return: The awc of this DepthReading.  # noqa: E501
        :rtype: float
        """
        return self._awc

    @awc.setter
    def awc(self, awc):
        """Sets the awc of this DepthReading.


        :param awc: The awc of this DepthReading.  # noqa: E501
        :type: float
        """

        self._awc = awc

    @property
    def soil_moisture(self):
        """Gets the soil_moisture of this DepthReading.  # noqa: E501

        Soil Moisture  # noqa: E501

        :return: The soil_moisture of this DepthReading.  # noqa: E501
        :rtype: float
        """
        return self._soil_moisture

    @soil_moisture.setter
    def soil_moisture(self, soil_moisture):
        """Sets the soil_moisture of this DepthReading.

        Soil Moisture  # noqa: E501

        :param soil_moisture: The soil_moisture of this DepthReading.  # noqa: E501
        :type: float
        """

        self._soil_moisture = soil_moisture

    @property
    def soil_temperature(self):
        """Gets the soil_temperature of this DepthReading.  # noqa: E501

        Soil Temperature  # noqa: E501

        :return: The soil_temperature of this DepthReading.  # noqa: E501
        :rtype: float
        """
        return self._soil_temperature

    @soil_temperature.setter
    def soil_temperature(self, soil_temperature):
        """Sets the soil_temperature of this DepthReading.

        Soil Temperature  # noqa: E501

        :param soil_temperature: The soil_temperature of this DepthReading.  # noqa: E501
        :type: float
        """

        self._soil_temperature = soil_temperature

    @property
    def soil_texture(self):
        """Gets the soil_texture of this DepthReading.  # noqa: E501

        Soil texture type. Data are collected from government data sources (USDA's SSURGO database for fields in the United States)  # noqa: E501

        :return: The soil_texture of this DepthReading.  # noqa: E501
        :rtype: str
        """
        return self._soil_texture

    @soil_texture.setter
    def soil_texture(self, soil_texture):
        """Sets the soil_texture of this DepthReading.

        Soil texture type. Data are collected from government data sources (USDA's SSURGO database for fields in the United States)  # noqa: E501

        :param soil_texture: The soil_texture of this DepthReading.  # noqa: E501
        :type: str
        """

        self._soil_texture = soil_texture

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DepthReading):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    teralytic

    Teralytic-API allows customers and partners to view their probes, sensor readings for each, as well as analytics and calculations from Teralytic algorithms.  # noqa: E501

    OpenAPI spec version: 1.0.5
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from teralytic.models.depth_reading import DepthReading  # noqa: F401,E501
from teralytic.models.micro_climate_data import MicroClimateData  # noqa: F401,E501
from teralytic.models.reading_location import ReadingLocation  # noqa: F401,E501
from teralytic.models.weather_data import WeatherData  # noqa: F401,E501


class Reading(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'probe_id': 'str',
        'probe_name': 'str',
        'field_id': 'str',
        'timestamp': 'str',
        'location': 'ReadingLocation',
        'probe': 'list[DepthReading]',
        'micro_climate': 'MicroClimateData',
        'macro_climate': 'WeatherData'
    }

    attribute_map = {
        'id': 'id',
        'probe_id': 'probe_id',
        'probe_name': 'probe_name',
        'field_id': 'field_id',
        'timestamp': 'timestamp',
        'location': 'location',
        'probe': 'probe',
        'micro_climate': 'micro_climate',
        'macro_climate': 'macro_climate'
    }

    def __init__(self, id=None, probe_id=None, probe_name=None, field_id=None, timestamp=None, location=None, probe=None, micro_climate=None, macro_climate=None):  # noqa: E501
        """Reading - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._probe_id = None
        self._probe_name = None
        self._field_id = None
        self._timestamp = None
        self._location = None
        self._probe = None
        self._micro_climate = None
        self._macro_climate = None
        self.discriminator = None

        self.id = id
        self.probe_id = probe_id
        if probe_name is not None:
            self.probe_name = probe_name
        if field_id is not None:
            self.field_id = field_id
        if timestamp is not None:
            self.timestamp = timestamp
        if location is not None:
            self.location = location
        if probe is not None:
            self.probe = probe
        if micro_climate is not None:
            self.micro_climate = micro_climate
        if macro_climate is not None:
            self.macro_climate = macro_climate

    @property
    def id(self):
        """Gets the id of this Reading.  # noqa: E501

        Base58 encoded identifier for this Reading. Corresponds with a single Probe and single timestamp.  # noqa: E501

        :return: The id of this Reading.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Reading.

        Base58 encoded identifier for this Reading. Corresponds with a single Probe and single timestamp.  # noqa: E501

        :param id: The id of this Reading.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def probe_id(self):
        """Gets the probe_id of this Reading.  # noqa: E501

        id of probe from which Reading was made  # noqa: E501

        :return: The probe_id of this Reading.  # noqa: E501
        :rtype: str
        """
        return self._probe_id

    @probe_id.setter
    def probe_id(self, probe_id):
        """Sets the probe_id of this Reading.

        id of probe from which Reading was made  # noqa: E501

        :param probe_id: The probe_id of this Reading.  # noqa: E501
        :type: str
        """
        if probe_id is None:
            raise ValueError("Invalid value for `probe_id`, must not be `None`")  # noqa: E501

        self._probe_id = probe_id

    @property
    def probe_name(self):
        """Gets the probe_name of this Reading.  # noqa: E501

        Name of probe from which Reading was made  # noqa: E501

        :return: The probe_name of this Reading.  # noqa: E501
        :rtype: str
        """
        return self._probe_name

    @probe_name.setter
    def probe_name(self, probe_name):
        """Sets the probe_name of this Reading.

        Name of probe from which Reading was made  # noqa: E501

        :param probe_name: The probe_name of this Reading.  # noqa: E501
        :type: str
        """

        self._probe_name = probe_name

    @property
    def field_id(self):
        """Gets the field_id of this Reading.  # noqa: E501

        The field id of the probe  # noqa: E501

        :return: The field_id of this Reading.  # noqa: E501
        :rtype: str
        """
        return self._field_id

    @field_id.setter
    def field_id(self, field_id):
        """Sets the field_id of this Reading.

        The field id of the probe  # noqa: E501

        :param field_id: The field_id of this Reading.  # noqa: E501
        :type: str
        """

        self._field_id = field_id

    @property
    def timestamp(self):
        """Gets the timestamp of this Reading.  # noqa: E501

        Time when Reading was measured  # noqa: E501

        :return: The timestamp of this Reading.  # noqa: E501
        :rtype: str
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this Reading.

        Time when Reading was measured  # noqa: E501

        :param timestamp: The timestamp of this Reading.  # noqa: E501
        :type: str
        """

        self._timestamp = timestamp

    @property
    def location(self):
        """Gets the location of this Reading.  # noqa: E501


        :return: The location of this Reading.  # noqa: E501
        :rtype: ReadingLocation
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this Reading.


        :param location: The location of this Reading.  # noqa: E501
        :type: ReadingLocation
        """

        self._location = location

    @property
    def probe(self):
        """Gets the probe of this Reading.  # noqa: E501

        Probe readings  # noqa: E501

        :return: The probe of this Reading.  # noqa: E501
        :rtype: list[DepthReading]
        """
        return self._probe

    @probe.setter
    def probe(self, probe):
        """Sets the probe of this Reading.

        Probe readings  # noqa: E501

        :param probe: The probe of this Reading.  # noqa: E501
        :type: list[DepthReading]
        """

        self._probe = probe

    @property
    def micro_climate(self):
        """Gets the micro_climate of this Reading.  # noqa: E501


        :return: The micro_climate of this Reading.  # noqa: E501
        :rtype: MicroClimateData
        """
        return self._micro_climate

    @micro_climate.setter
    def micro_climate(self, micro_climate):
        """Sets the micro_climate of this Reading.


        :param micro_climate: The micro_climate of this Reading.  # noqa: E501
        :type: MicroClimateData
        """

        self._micro_climate = micro_climate

    @property
    def macro_climate(self):
        """Gets the macro_climate of this Reading.  # noqa: E501


        :return: The macro_climate of this Reading.  # noqa: E501
        :rtype: WeatherData
        """
        return self._macro_climate

    @macro_climate.setter
    def macro_climate(self, macro_climate):
        """Sets the macro_climate of this Reading.


        :param macro_climate: The macro_climate of this Reading.  # noqa: E501
        :type: WeatherData
        """

        self._macro_climate = macro_climate

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Reading):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    teralytic

    Teralytic-API allows customers and partners to view their probes, sensor readings for each, as well as analytics and calculations from Teralytic algorithms.  # noqa: E501

    OpenAPI spec version: 1.0.5
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import teralytic
from teralytic.api.field_api import FieldApi  # noqa: E501
from teralytic.rest import ApiException


class TestFieldApi(unittest.TestCase):
    """FieldApi unit test stubs"""

    def setUp(self):
        self.api = teralytic.api.field_api.FieldApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_field_get(self):
        """Test case for field_get

        List single Field details associated with Field id provided (from set of Fields associated with the account key)  # noqa: E501
        """
        pass

    def test_field_list(self):
        """Test case for field_list

        List all Fields associated with account key  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    teralytic

    Teralytic-API allows customers and partners to view their probes, sensor readings for each, as well as analytics and calculations from Teralytic algorithms.  # noqa: E501

    OpenAPI spec version: 1.0.5
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from teralytic.api_client import ApiClient


class ProbeApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def probe_get(self, organization_id, probe_id, **kwargs):  # noqa: E501
        """List single Probe details, including Reading data, associated with Probe id provided (from set of Fields associated with the account key)  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.probe_get(organization_id, probe_id, async=True)
        >>> result = thread.get()

        :param async bool
        :param str organization_id: id of Organization to retrieve (required)
        :param str probe_id: id of Probe to retrieve (required)
        :return: Probe
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.probe_get_with_http_info(organization_id, probe_id, **kwargs)  # noqa: E501
        else:
            (data) = self.probe_get_with_http_info(organization_id, probe_id, **kwargs)  # noqa: E501
            return data

    def probe_get_with_http_info(self, organization_id, probe_id, **kwargs):  # noqa: E501
        """List single Probe details, including Reading data, associated with Probe id provided (from set of Fields associated with the account key)  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.probe_get_with_http_info(organization_id, probe_id, async=True)
        >>> result = thread.get()

        :param async bool
        :param str organization_id: id of Organization to retrieve (required)
        :param str probe_id: id of Probe to retrieve (required)
        :return: Probe
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['organization_id', 'probe_id']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method probe_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'organization_id' is set
        if ('organization_id' not in params or
                params['organization_id'] is None):
            raise ValueError("Missing the required parameter `organization_id` when calling `probe_get`")  # noqa: E501
        # verify the required parameter 'probe_id' is set
        if ('probe_id' not in params or
                params['probe_id'] is None):
            raise ValueError("Missing the required parameter `probe_id` when calling `probe_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'organization_id' in params:
            path_params['organization_id'] = params['organization_id']  # noqa: E501
        if 'probe_id' in params:
            path_params['probe_id'] = params['probe_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/organizations/{organization_id}/probes/{probe_id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Probe',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def probe_list(self, organization_id, **kwargs):  # noqa: E501
        """List all Probes associated with account key  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.probe_list(organization_id, async=True)
        >>> result = thread.get()

        :param async bool
        :param str organization_id: id of Organization to retrieve (required)
        :param list[str] fields: Fields to filter search on
        :return: list[Probe]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.probe_list_with_http_info(organization_id, **kwargs)  # noqa: E501
        else:
            (data) = self.probe_list_with_http_info(organization_id, **kwargs)  # noqa: E501
            return data

    def probe_list_with_http_info(self, organization_id, **kwargs):  # noqa: E501
        """List all Probes associated with account key  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.probe_list_with_http_info(organization_id, async=True)
        >>> result = thread.get()

        :param async bool
        :param str organization_id: id of Organization to retrieve (required)
        :param list[str] fields: Fields to filter search on
        :return: list[Probe]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['organization_id', 'fields']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method probe_list" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'organization_id' is set
        if ('organization_id' not in params or
                params['organization_id'] is None):
            raise ValueError("Missing the required parameter `organization_id` when calling `probe_list`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'organization_id' in params:
            path_params['organization_id'] = params['organization_id']  # noqa: E501

        query_params = []
        if 'fields' in params:
            query_params.append(('fields', params['fields']))  # noqa: E501
            collection_formats['fields'] = 'csv'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/organizations/{organization_id}/probes', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Probe]',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    teralytic

    Teralytic-API allows customers and partners to view their probes, sensor readings for each, as well as analytics and calculations from Teralytic algorithms.  # noqa: E501

    OpenAPI spec version: 1.0.5
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class MicroClimateData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'humidity': 'float',
        'irrigation_sched': 'int',
        'irrigation_vol_acre_in': 'float',
        'irrigation_vol_acre_cm': 'float',
        'lux': 'float',
        'irrigation_gross_in': 'float',
        'irrigation_net_in': 'float',
        'irrigation_gross_cm': 'float',
        'irrigation_net_cm': 'float',
        'irrigation_rec': 'str',
        'temperature': 'float',
        'eto': 'float',
        'irrigation_stream': 'float',
        'organic_matter': 'float'
    }

    attribute_map = {
        'humidity': 'humidity',
        'irrigation_sched': 'irrigation_sched',
        'irrigation_vol_acre_in': 'irrigation_vol_acre_in',
        'irrigation_vol_acre_cm': 'irrigation_vol_acre_cm',
        'lux': 'lux',
        'irrigation_gross_in': 'irrigation_gross_in',
        'irrigation_net_in': 'irrigation_net_in',
        'irrigation_gross_cm': 'irrigation_gross_cm',
        'irrigation_net_cm': 'irrigation_net_cm',
        'irrigation_rec': 'irrigation_rec',
        'temperature': 'temperature',
        'eto': 'eto',
        'irrigation_stream': 'irrigation_stream',
        'organic_matter': 'organic_matter'
    }

    def __init__(self, humidity=None, irrigation_sched=None, irrigation_vol_acre_in=None, irrigation_vol_acre_cm=None, lux=None, irrigation_gross_in=None, irrigation_net_in=None, irrigation_gross_cm=None, irrigation_net_cm=None, irrigation_rec=None, temperature=None, eto=None, irrigation_stream=None, organic_matter=None):  # noqa: E501
        """MicroClimateData - a model defined in Swagger"""  # noqa: E501

        self._humidity = None
        self._irrigation_sched = None
        self._irrigation_vol_acre_in = None
        self._irrigation_vol_acre_cm = None
        self._lux = None
        self._irrigation_gross_in = None
        self._irrigation_net_in = None
        self._irrigation_gross_cm = None
        self._irrigation_net_cm = None
        self._irrigation_rec = None
        self._temperature = None
        self._eto = None
        self._irrigation_stream = None
        self._organic_matter = None
        self.discriminator = None

        if humidity is not None:
            self.humidity = humidity
        if irrigation_sched is not None:
            self.irrigation_sched = irrigation_sched
        if irrigation_vol_acre_in is not None:
            self.irrigation_vol_acre_in = irrigation_vol_acre_in
        if irrigation_vol_acre_cm is not None:
            self.irrigation_vol_acre_cm = irrigation_vol_acre_cm
        if lux is not None:
            self.lux = lux
        if irrigation_gross_in is not None:
            self.irrigation_gross_in = irrigation_gross_in
        if irrigation_net_in is not None:
            self.irrigation_net_in = irrigation_net_in
        if irrigation_gross_cm is not None:
            self.irrigation_gross_cm = irrigation_gross_cm
        if irrigation_net_cm is not None:
            self.irrigation_net_cm = irrigation_net_cm
        if irrigation_rec is not None:
            self.irrigation_rec = irrigation_rec
        if temperature is not None:
            self.temperature = temperature
        if eto is not None:
            self.eto = eto
        if irrigation_stream is not None:
            self.irrigation_stream = irrigation_stream
        if organic_matter is not None:
            self.organic_matter = organic_matter

    @property
    def humidity(self):
        """Gets the humidity of this MicroClimateData.  # noqa: E501


        :return: The humidity of this MicroClimateData.  # noqa: E501
        :rtype: float
        """
        return self._humidity

    @humidity.setter
    def humidity(self, humidity):
        """Sets the humidity of this MicroClimateData.


        :param humidity: The humidity of this MicroClimateData.  # noqa: E501
        :type: float
        """

        self._humidity = humidity

    @property
    def irrigation_sched(self):
        """Gets the irrigation_sched of this MicroClimateData.  # noqa: E501

        Irrigation Schedule  # noqa: E501

        :return: The irrigation_sched of this MicroClimateData.  # noqa: E501
        :rtype: int
        """
        return self._irrigation_sched

    @irrigation_sched.setter
    def irrigation_sched(self, irrigation_sched):
        """Sets the irrigation_sched of this MicroClimateData.

        Irrigation Schedule  # noqa: E501

        :param irrigation_sched: The irrigation_sched of this MicroClimateData.  # noqa: E501
        :type: int
        """

        self._irrigation_sched = irrigation_sched

    @property
    def irrigation_vol_acre_in(self):
        """Gets the irrigation_vol_acre_in of this MicroClimateData.  # noqa: E501

        Irrigation volume in3/acre  # noqa: E501

        :return: The irrigation_vol_acre_in of this MicroClimateData.  # noqa: E501
        :rtype: float
        """
        return self._irrigation_vol_acre_in

    @irrigation_vol_acre_in.setter
    def irrigation_vol_acre_in(self, irrigation_vol_acre_in):
        """Sets the irrigation_vol_acre_in of this MicroClimateData.

        Irrigation volume in3/acre  # noqa: E501

        :param irrigation_vol_acre_in: The irrigation_vol_acre_in of this MicroClimateData.  # noqa: E501
        :type: float
        """

        self._irrigation_vol_acre_in = irrigation_vol_acre_in

    @property
    def irrigation_vol_acre_cm(self):
        """Gets the irrigation_vol_acre_cm of this MicroClimateData.  # noqa: E501

        Irrigation volume c3/acre  # noqa: E501

        :return: The irrigation_vol_acre_cm of this MicroClimateData.  # noqa: E501
        :rtype: float
        """
        return self._irrigation_vol_acre_cm

    @irrigation_vol_acre_cm.setter
    def irrigation_vol_acre_cm(self, irrigation_vol_acre_cm):
        """Sets the irrigation_vol_acre_cm of this MicroClimateData.

        Irrigation volume c3/acre  # noqa: E501

        :param irrigation_vol_acre_cm: The irrigation_vol_acre_cm of this MicroClimateData.  # noqa: E501
        :type: float
        """

        self._irrigation_vol_acre_cm = irrigation_vol_acre_cm

    @property
    def lux(self):
        """Gets the lux of this MicroClimateData.  # noqa: E501


        :return: The lux of this MicroClimateData.  # noqa: E501
        :rtype: float
        """
        return self._lux

    @lux.setter
    def lux(self, lux):
        """Sets the lux of this MicroClimateData.


        :param lux: The lux of this MicroClimateData.  # noqa: E501
        :type: float
        """

        self._lux = lux

    @property
    def irrigation_gross_in(self):
        """Gets the irrigation_gross_in of this MicroClimateData.  # noqa: E501

        Gross irrigation in in3  # noqa: E501

        :return: The irrigation_gross_in of this MicroClimateData.  # noqa: E501
        :rtype: float
        """
        return self._irrigation_gross_in

    @irrigation_gross_in.setter
    def irrigation_gross_in(self, irrigation_gross_in):
        """Sets the irrigation_gross_in of this MicroClimateData.

        Gross irrigation in in3  # noqa: E501

        :param irrigation_gross_in: The irrigation_gross_in of this MicroClimateData.  # noqa: E501
        :type: float
        """

        self._irrigation_gross_in = irrigation_gross_in

    @property
    def irrigation_net_in(self):
        """Gets the irrigation_net_in of this MicroClimateData.  # noqa: E501

        Net irrigation in in3  # noqa: E501

        :return: The irrigation_net_in of this MicroClimateData.  # noqa: E501
        :rtype: float
        """
        return self._irrigation_net_in

    @irrigation_net_in.setter
    def irrigation_net_in(self, irrigation_net_in):
        """Sets the irrigation_net_in of this MicroClimateData.

        Net irrigation in in3  # noqa: E501

        :param irrigation_net_in: The irrigation_net_in of this MicroClimateData.  # noqa: E501
        :type: float
        """

        self._irrigation_net_in = irrigation_net_in

    @property
    def irrigation_gross_cm(self):
        """Gets the irrigation_gross_cm of this MicroClimateData.  # noqa: E501

        Gross irrigation in cm3  # noqa: E501

        :return: The irrigation_gross_cm of this MicroClimateData.  # noqa: E501
        :rtype: float
        """
        return self._irrigation_gross_cm

    @irrigation_gross_cm.setter
    def irrigation_gross_cm(self, irrigation_gross_cm):
        """Sets the irrigation_gross_cm of this MicroClimateData.

        Gross irrigation in cm3  # noqa: E501

        :param irrigation_gross_cm: The irrigation_gross_cm of this MicroClimateData.  # noqa: E501
        :type: float
        """

        self._irrigation_gross_cm = irrigation_gross_cm

    @property
    def irrigation_net_cm(self):
        """Gets the irrigation_net_cm of this MicroClimateData.  # noqa: E501

        Net irrigation in cm3  # noqa: E501

        :return: The irrigation_net_cm of this MicroClimateData.  # noqa: E501
        :rtype: float
        """
        return self._irrigation_net_cm

    @irrigation_net_cm.setter
    def irrigation_net_cm(self, irrigation_net_cm):
        """Sets the irrigation_net_cm of this MicroClimateData.

        Net irrigation in cm3  # noqa: E501

        :param irrigation_net_cm: The irrigation_net_cm of this MicroClimateData.  # noqa: E501
        :type: float
        """

        self._irrigation_net_cm = irrigation_net_cm

    @property
    def irrigation_rec(self):
        """Gets the irrigation_rec of this MicroClimateData.  # noqa: E501

        Irrigation recommendation  # noqa: E501

        :return: The irrigation_rec of this MicroClimateData.  # noqa: E501
        :rtype: str
        """
        return self._irrigation_rec

    @irrigation_rec.setter
    def irrigation_rec(self, irrigation_rec):
        """Sets the irrigation_rec of this MicroClimateData.

        Irrigation recommendation  # noqa: E501

        :param irrigation_rec: The irrigation_rec of this MicroClimateData.  # noqa: E501
        :type: str
        """

        self._irrigation_rec = irrigation_rec

    @property
    def temperature(self):
        """Gets the temperature of this MicroClimateData.  # noqa: E501

        Air Temperature  # noqa: E501

        :return: The temperature of this MicroClimateData.  # noqa: E501
        :rtype: float
        """
        return self._temperature

    @temperature.setter
    def temperature(self, temperature):
        """Sets the temperature of this MicroClimateData.

        Air Temperature  # noqa: E501

        :param temperature: The temperature of this MicroClimateData.  # noqa: E501
        :type: float
        """

        self._temperature = temperature

    @property
    def eto(self):
        """Gets the eto of this MicroClimateData.  # noqa: E501

        Evaporative Transpiration  # noqa: E501

        :return: The eto of this MicroClimateData.  # noqa: E501
        :rtype: float
        """
        return self._eto

    @eto.setter
    def eto(self, eto):
        """Sets the eto of this MicroClimateData.

        Evaporative Transpiration  # noqa: E501

        :param eto: The eto of this MicroClimateData.  # noqa: E501
        :type: float
        """

        self._eto = eto

    @property
    def irrigation_stream(self):
        """Gets the irrigation_stream of this MicroClimateData.  # noqa: E501


        :return: The irrigation_stream of this MicroClimateData.  # noqa: E501
        :rtype: float
        """
        return self._irrigation_stream

    @irrigation_stream.setter
    def irrigation_stream(self, irrigation_stream):
        """Sets the irrigation_stream of this MicroClimateData.


        :param irrigation_stream: The irrigation_stream of this MicroClimateData.  # noqa: E501
        :type: float
        """

        self._irrigation_stream = irrigation_stream

    @property
    def organic_matter(self):
        """Gets the organic_matter of this MicroClimateData.  # noqa: E501

        Organic Matter  # noqa: E501

        :return: The organic_matter of this MicroClimateData.  # noqa: E501
        :rtype: float
        """
        return self._organic_matter

    @organic_matter.setter
    def organic_matter(self, organic_matter):
        """Sets the organic_matter of this MicroClimateData.

        Organic Matter  # noqa: E501

        :param organic_matter: The organic_matter of this MicroClimateData.  # noqa: E501
        :type: float
        """

        self._organic_matter = organic_matter

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MicroClimateData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    teralytic

    Teralytic-API allows customers and partners to view their probes, sensor readings for each, as well as analytics and calculations from Teralytic algorithms.  # noqa: E501

    OpenAPI spec version: 1.0.5
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from teralytic.models.reading import Reading  # noqa: F401,E501


class Probe(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'serial_code': 'str',
        'field_id': 'str',
        'organization_id': 'str',
        'last_reading': 'Reading'
    }

    attribute_map = {
        'id': 'id',
        'serial_code': 'serial_code',
        'field_id': 'field_id',
        'organization_id': 'organization_id',
        'last_reading': 'last_reading'
    }

    def __init__(self, id=None, serial_code=None, field_id=None, organization_id=None, last_reading=None):  # noqa: E501
        """Probe - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._serial_code = None
        self._field_id = None
        self._organization_id = None
        self._last_reading = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if serial_code is not None:
            self.serial_code = serial_code
        if field_id is not None:
            self.field_id = field_id
        if organization_id is not None:
            self.organization_id = organization_id
        if last_reading is not None:
            self.last_reading = last_reading

    @property
    def id(self):
        """Gets the id of this Probe.  # noqa: E501


        :return: The id of this Probe.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Probe.


        :param id: The id of this Probe.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def serial_code(self):
        """Gets the serial_code of this Probe.  # noqa: E501


        :return: The serial_code of this Probe.  # noqa: E501
        :rtype: str
        """
        return self._serial_code

    @serial_code.setter
    def serial_code(self, serial_code):
        """Sets the serial_code of this Probe.


        :param serial_code: The serial_code of this Probe.  # noqa: E501
        :type: str
        """

        self._serial_code = serial_code

    @property
    def field_id(self):
        """Gets the field_id of this Probe.  # noqa: E501


        :return: The field_id of this Probe.  # noqa: E501
        :rtype: str
        """
        return self._field_id

    @field_id.setter
    def field_id(self, field_id):
        """Sets the field_id of this Probe.


        :param field_id: The field_id of this Probe.  # noqa: E501
        :type: str
        """

        self._field_id = field_id

    @property
    def organization_id(self):
        """Gets the organization_id of this Probe.  # noqa: E501


        :return: The organization_id of this Probe.  # noqa: E501
        :rtype: str
        """
        return self._organization_id

    @organization_id.setter
    def organization_id(self, organization_id):
        """Sets the organization_id of this Probe.


        :param organization_id: The organization_id of this Probe.  # noqa: E501
        :type: str
        """

        self._organization_id = organization_id

    @property
    def last_reading(self):
        """Gets the last_reading of this Probe.  # noqa: E501


        :return: The last_reading of this Probe.  # noqa: E501
        :rtype: Reading
        """
        return self._last_reading

    @last_reading.setter
    def last_reading(self, last_reading):
        """Sets the last_reading of this Probe.


        :param last_reading: The last_reading of this Probe.  # noqa: E501
        :type: Reading
        """

        self._last_reading = last_reading

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Probe):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa

"""
    teralytic

    Teralytic-API allows customers and partners to view their probes, sensor readings for each, as well as analytics and calculations from Teralytic algorithms.  # noqa: E501

    OpenAPI spec version: 1.0.5
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import apis into sdk package
from teralytic.api.field_api import FieldApi
from teralytic.api.organization_api import OrganizationApi
from teralytic.api.probe_api import ProbeApi

# import ApiClient
from teralytic.api_client import ApiClient
from teralytic.configuration import Configuration
# import models into sdk package
from teralytic.models.depth_reading import DepthReading
from teralytic.models.error import Error
from teralytic.models.field import Field
from teralytic.models.field_geometry import FieldGeometry
from teralytic.models.field_geometry_geometry import FieldGeometryGeometry
from teralytic.models.micro_climate_data import MicroClimateData
from teralytic.models.organization import Organization
from teralytic.models.probe import Probe
from teralytic.models.reading import Reading
from teralytic.models.reading_location import ReadingLocation
from teralytic.models.weather_data import WeatherData
